EXPORTS
	__14NaviEngineAssp @ 1 NONAME R3UNUSED ; NaviEngineAssp::NaviEngineAssp(void)
	Bind__9InterruptiPFPv_vPv @ 2 NONAME R3UNUSED ; Interrupt::Bind(int, void (*)(void *), void *)
	BootWaitMilliSeconds__11TNaviEnginei @ 3 NONAME R3UNUSED ; TNaviEngine::BootWaitMilliSeconds(int)
	Clear__9Interrupti @ 4 NONAME R3UNUSED ; Interrupt::Clear(int)
	CpuVersionId__11TNaviEngine @ 5 NONAME R3UNUSED ; TNaviEngine::CpuVersionId(void)
	DebugOutput__14NaviEngineAsspUi @ 6 NONAME R3UNUSED ; NaviEngineAssp::DebugOutput(unsigned int)
	DebugPortAddr__11TNaviEngine @ 7 NONAME R3UNUSED ; TNaviEngine::DebugPortAddr(void)
	Disable__9Interrupti @ 8 NONAME R3UNUSED ; Interrupt::Disable(int)
	Enable__9Interrupti @ 9 NONAME R3UNUSED ; Interrupt::Enable(int)
	Init1__14NaviEngineAssp @ 10 NONAME R3UNUSED ; NaviEngineAssp::Init1(void)
	Init3__14NaviEngineAssp @ 11 NONAME R3UNUSED ; NaviEngineAssp::Init3(void)
	Modify16__12AsspRegisterUlUsUs @ 12 NONAME R3UNUSED ; AsspRegister::Modify16(unsigned long, unsigned short, unsigned short)
	Modify32__12AsspRegisterUlUlUl @ 13 NONAME R3UNUSED ; AsspRegister::Modify32(unsigned long, unsigned long, unsigned long)
	Modify64__12AsspRegisterUlUxUx @ 14 NONAME ; AsspRegister::Modify64(unsigned long, unsigned long long, unsigned long long)
	Modify8__12AsspRegisterUlUcUc @ 15 NONAME R3UNUSED ; AsspRegister::Modify8(unsigned long, unsigned char, unsigned char)
	MsTickPeriod__14NaviEngineAssp @ 16 NONAME R3UNUSED ; NaviEngineAssp::MsTickPeriod(void)
	NanoWaitCalibration__14NaviEngineAssp @ 17 NONAME R3UNUSED ; NaviEngineAssp::NanoWaitCalibration(void)
	ProcessorPeriodInPs__11TNaviEngine @ 18 NONAME R3UNUSED ; TNaviEngine::ProcessorPeriodInPs(void)
	Read64__12AsspRegisterUl @ 19 NONAME R3UNUSED ; AsspRegister::Read64(unsigned long)
	RtcData__11TNaviEngine @ 20 NONAME R3UNUSED ; TNaviEngine::RtcData(void)
	SetPriority__9Interruptii @ 21 NONAME R3UNUSED ; Interrupt::SetPriority(int, int)
	SetRtcData__11TNaviEngineUi @ 22 NONAME R3UNUSED ; TNaviEngine::SetRtcData(unsigned int)
	SetSystemTimeInSecondsFrom2000__14NaviEngineAsspi @ 23 NONAME R3UNUSED ; NaviEngineAssp::SetSystemTimeInSecondsFrom2000(int)
	StartupReason__11TNaviEngine @ 24 NONAME R3UNUSED ; TNaviEngine::StartupReason(void)
	StartupReason__14NaviEngineAssp @ 25 NONAME R3UNUSED ; NaviEngineAssp::StartupReason(void)
	SystemTimeInSecondsFrom2000__14NaviEngineAsspRi @ 26 NONAME R3UNUSED ; NaviEngineAssp::SystemTimeInSecondsFrom2000(int &)
	Unbind__9Interrupti @ 27 NONAME R3UNUSED ; Interrupt::Unbind(int)
	VideoRamPhys__11TNaviEngine @ 28 NONAME R3UNUSED ; TNaviEngine::VideoRamPhys(void)
	Write64__12AsspRegisterUlUx @ 29 NONAME ; AsspRegister::Write64(unsigned long, unsigned long long)
	AsicInitialise__Fv @ 30 NONAME R3UNUSED ; AsicInitialise(void)

